@@ -1,18 +1,17 @@
 /*
-@version: 0.1
+@version: 0.2
 @author: Sudheer K. <scifi.guy@hotmail.com>
 @license: GNU General Public License
 */
 
-#include <QtGui/QApplication>
-#include "configwidget.h"
-#include <QDebug>
 
+#include <QtGui/QApplication>
+#include "configwindow.h"
 int main(int argc, char *argv[])
 {
 
     QApplication a(argc, argv);            
-    ConfigWidget w;
+    ConfigWindow w;
     w.show();
     return a.exec();
 }
