@@ -1,5 +1,5 @@
 /*
-@version: 0.1
+@version: 0.2
 @author: Sudheer K. <scifi.guy@hotmail.com>
 @license: GNU General Public License
 */
@@ -183,7 +183,7 @@ void CallRouter::stopOutgoingCallMonitor(){
 void CallRouter::processOutgoingCall(const QDBusMessage& dbusMessage){
 
     //Verify Whether Call Routing is Enabled
-    bool isRoutingEnabled = gconfUtility->getGconfValueBoolean((char *)"routing_enabled");    
+    bool isRoutingEnabled = gconfUtility->getGconfValueBoolean("routing_enabled");
 
     if (isRoutingEnabled){
         //User is making a phone call. Get the phone number and verify if it is an international number
@@ -235,8 +235,7 @@ void CallRouter::processOutgoingCall(const QDBusMessage& dbusMessage){
 void CallRouter::callViaCallingCard(){
         //Now call the calling card number. This is generally a local and/or tollfree number
 
-        char *charCallingCardNumber = gconfUtility->getGconfValueString((char *)"calling_card_number");
-        QString strCallingCardNumber = QString(charCallingCardNumber);
+        QString strCallingCardNumber = gconfUtility->getGconfValueString("calling_card_number");
 
         qDebug() << "Wait time elapsed. Initiating call to "<< strCallingCardNumber;
 
@@ -437,9 +436,8 @@ QString CallRouter::convertToDTMFCode(QString strNumber){
     if (!strNumber.isEmpty()){
 
         //Get the format required by calling card from coniguration
-        char *strDTMFFormat = gconfUtility->getGconfValueString((char *)"dtmf_format");
-        QString qstrDTMFFormat = QString(strDTMFFormat);
-        int intDTMFDelay = gconfUtility->getGconfValueInteger((char *)"dtmf_delay");                
+        QString qstrDTMFFormat = gconfUtility->getGconfValueString("dtmf_format");
+        int intDTMFDelay = gconfUtility->getGconfValueInteger("dtmf_delay");
 
         if (intDTMFDelay <1 ) intDTMFDelay = 1;
         if (qstrDTMFFormat.isEmpty()) qstrDTMFFormat = "<Country Code><Area Code><Phone Number>";
@@ -468,6 +466,12 @@ QString CallRouter::convertToDTMFCode(QString strNumber){
         //Default case - we don't need any prefix
 
         strDTMFCode = strDTMFCode.append(strNumber);
+
+        //Now check whether we need a suffix
+        QString strDTMFSuffix = gconfUtility->getGconfValueString("dtmf_suffix");
+        if (!strDTMFSuffix.isEmpty() && !strDTMFSuffix.contains("--None--")){
+            strDTMFCode = strDTMFCode.append(strDTMFSuffix);
+        }
     }
 
     return strDTMFCode;
@@ -478,8 +482,7 @@ bool CallRouter::isExcludedNumber(QString strInternationalNumber){
     bool isExcluded = false;
 
     //Get the list of excluded codes
-    char* strExcludedNumbers = gconfUtility->getGconfValueString((char *)"numbers_to_exclude");
-    QString qstrExcludedNumbers = QString(strExcludedNumbers);
+    QString qstrExcludedNumbers = gconfUtility->getGconfValueString("numbers_to_exclude");
     QStringList strExcludedCodeList = qstrExcludedNumbers.split(",");
     QStringListIterator iterator(strExcludedCodeList);
 
