@@ -1,5 +1,5 @@
 /*
-@version: 0.1
+@version: 0.2
 @author: Sudheer K. <scifi.guy@hotmail.com>
 @license: GNU General Public License
 */
@@ -19,14 +19,14 @@ Q_OBJECT
 public:
     GConfUtility(QObject *parent = 0);
     ~GConfUtility();
-    void setGconfValueString(char *strKey,char *strValue);
-    char* getGconfValueString(char *strKey);
+    void setGconfValueString(QString strKey,QString strValue);
+    QString getGconfValueString(QString strKey);
 
-    void setGconfValueBoolean(char *strKey,bool boolValue);
-    bool getGconfValueBoolean(char *strKey);
+    void setGconfValueBoolean(QString strKey,bool boolValue);
+    bool getGconfValueBoolean(QString strKey);
 
-    void setGconfValueInteger(char *strKey,int intValue);
-    int getGconfValueInteger(char *strKey);
+    void setGconfValueInteger(QString strKey,int intValue);
+    int getGconfValueInteger(QString strKey);
 
 private:
      GConfClient *gconfClient;
